reinit.variables <-
function() {
  tclvalue(Env$l.var$variable)<-""
  tclvalue(Env$l.var$facteur1)<-""
  tclvalue(Env$l.var$niveau)<-""
  tclvalue(Env$l.var$hist.type)<-""
  tclvalue(Env$l.var$encadre)<-0
  tclvalue(Env$l.var$titre)<-""
  tclvalue(Env$l.var$titre.col)<-"black"
  tclvalue(Env$l.var$titre.taille)<-"1.5"
  tclvalue(Env$l.var$soustitre)<-""
  tclvalue(Env$l.var$graduations.col)<-"black"
  tclvalue(Env$l.var$graduations.taille)<-"1"
  tclvalue(Env$l.var$graduations.orient)<-Env$voc[246,1]
  tclvalue(Env$l.var$legendes.col)<-"black"
  tclvalue(Env$l.var$legendes.taille)<-"1"
  tclvalue(Env$l.var$titre.axehor)<-""
  tclvalue(Env$l.var$titre.axever)<-""
  tclvalue(Env$l.var$liminf.axehor)<-"Auto"
  tclvalue(Env$l.var$limsup.axehor)<-"Auto"
  tclvalue(Env$l.var$liminf.axever)<-"Auto"
  tclvalue(Env$l.var$limsup.axever)<-"Auto"
  tclvalue(Env$l.var$hist.barres)<-"Auto"
  tclvalue(Env$l.var$couleur1A)<-"grey"
  tclvalue(Env$l.var$col.borduresA)<-"black"
  tclvalue(Env$l.var$hist.dens)<-0
  tclvalue(Env$l.var$couleur2A)<-"black"
  tclvalue(Env$l.var$trait1)<-""
  tclvalue(Env$l.var$epaisseur1)<-"1"
  Env$l.var$facteur.interaction<-""
  tclvalue(Env$l.var$box.orient)<-""
  tclvalue(Env$l.var$titre.axenoms)<-""
  tclvalue(Env$l.var$titre.axevaleurs)<-""
  tclvalue(Env$l.var$liminf.axevaleurs)<-"Auto"
  tclvalue(Env$l.var$limsup.axevaleurs)<-"Auto"
  tclvalue(Env$l.var$log.axevaleurs)<-0
  tclvalue(Env$l.var$boxmoy)<-0
  tclvalue(Env$l.var$ICmediane)<-0
  tclvalue(Env$l.var$varwidth)<-0
  tclvalue(Env$l.var$lg.moustaches)<-"1.5"
  tclvalue(Env$l.var$outliers)<-1
  tclvalue(Env$l.var$box.symbol)<-""
  Env$l.var$noms1<-""
  tclvalue(Env$l.var$moyprop)<-"moy"
  tclvalue(Env$l.var$facteur2)<-""
  tclvalue(Env$l.var$proportions)<-""
  tclvalue(Env$l.var$prop.niveaux)<-""
  Env$l.var$nomsprop<-""
  tclvalue(Env$l.var$moyprop)<-"moy"
  tclvalue(Env$l.var$facteurprop)<-""
  Env$l.var$couleur1B<-"white"
  Env$l.var$col.borduresB<-"black"
  tclvalue(Env$l.var$hachuresA)<-"1"
  Env$l.var$hachuresB<-1
  tclvalue(Env$l.var$stack)<-0
  tclvalue(Env$l.var$erreur)<-""
  tclvalue(Env$l.var$legende)<-0
  tclvalue(Env$l.var$legende.pos)<-""
  tclvalue(Env$l.var$legende.titre)<-""
  Env$l.var$noms2<-""
  tclvalue(Env$l.var$plusieurs)<-0
  Env$l.var$nomsprop.fac<-""
  tclvalue(Env$l.var$cam.orient)<-""
  tclvalue(Env$l.var$cam.start)<-"0"
  tclvalue(Env$l.var$cam.lien)<-0
  tclvalue(Env$l.var$parts.niveaux)<-""
  Env$l.var$nomsparts<-""
  tclvalue(Env$l.var$varX)<-""
  tclvalue(Env$l.var$varY)<-""
  tclvalue(Env$l.var$varX.prop)<-""
  Env$l.var$couleur2B<-"grey"
  tclvalue(Env$l.var$taille.ptsA)<-"1"
  Env$l.var$taille.ptsB<-1
  tclvalue(Env$l.var$type.courbeA)<-""
  Env$l.var$type.courbeB<-""
  Env$l.var$trait2<-""
  Env$l.var$epaisseur2<-1
  tclvalue(Env$l.var$symboleA)<-"1"
  Env$l.var$symboleB<-1
  Env$l.var$select<-1
  tclvalue(Env$l.var$droiteA)<-""
  Env$l.var$droiteB<-""
  tclvalue(Env$l.var$intervalA)<-""
  Env$l.var$intervalB<-""
  tclvalue(Env$l.var$ptlab)<-0
  tclvalue(Env$l.var$sysinfo)<-0
  Env$l.var$levels.temp <- NULL
  tclvalue(Env$l.var$nobar)<-0
  Env$l.var$add.abscisses<-NULL
  Env$l.var$add.hauteurs<-NULL
  Env$l.var$add.seq<-NULL
  Env$l.var$add.seq2<-NULL
  Env$l.var$add.matrice<-NULL
}
